/*=========================================================================

  Program: GDCM (Grassroots DICOM). A DICOM library
  Module:  $URL$

  Copyright (c) 2006-2010 Mathieu Malaterre
  All rights reserved.
  See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#ifndef GDCMSPECTROSCOPY_H
#define GDCMSPECTROSCOPY_H

#include "gdcmFile.h"

namespace gdcm
{
/**
 * \brief Spectroscopy class
 */
class GDCM_EXPORT Spectroscopy
{
public:
  Spectroscopy() {}

private:
};

} // end namespace gdcm

#endif //GDCMSPECTROSCOPY_H
